{% extends "datebook/base.html" %}
{% load i18n %}

{% block datebook_content %}
<p><a href="{% url 'datebook-current-day' author=user %}" class="button success large expand radius"><i class="icon-pencil"></i> {% blocktrans %}Fill your current day{% endblocktrans %}</a></p>

<hr/>

<ul class="inline-list">
        {% if user.is_superuser or perms.datebook.add_datebook %}<li>
            <a href="{% url 'datebook-create' %}" class="button success small radius"><i class="icon-add-circle"></i> {% blocktrans %}Open a new datebook for a new user{% endblocktrans %}</a>
        </li>{% endif %}
    {% spaceless %}{% for item in object_list %}
        <li>
            <a href="{% url 'datebook-author' author=item.author__username %}" class="button small radius">{{ item.author__username }}</a>
            {% comment %}<p>Updated on {{ item.modified|timesince }}</p>{% endcomment %}
        </li>
    {% endfor %}{% endspaceless %}
</ul>
 {% endblock %}
