{% load assets %}{% assets "datebook_app_css" %}
    <link rel="stylesheet" href="{{ ASSET_URL }}">
{% endassets %}
{% comment %}<link rel="stylesheet" href="{{ STATIC_URL }}css/datebook_app.css">{% endcomment %}