{% load i18n %}
<div class="inner">
    <div class="row item {% if object %} has-entry{% if object.vacation %} vacation{% endif %}{% endif %}">
        <div class="small-12 columns">
            <h3 class="text-center">{{ object.activity_date|date:"l d F" }}</h3>
            {% if object %}
                {% if object.vacation %}
                    <p class="empty text-center vacation-label">{% trans "Vacation" %}</p>
                {% else %}
                    <ul class="inline-list">
                        <li><span class="label round secondary"><i class="icon-clock"></i> {{ object.get_working_hours }}</span></li>
                        <li><span class="label round secondary"><i class="icon-timer"></i> {{ object.get_elapsed_time }}</li>
                        {% if object.get_overtime_seconds > 0 %}<li><span class="label round secondary"><i class="icon-starfull"></i> {{ object.get_overtime_time }}</span></li>{% endif %}
                    </ul>
                    {% if object.content %}
                        <div class="content">{{ object.content|linebreaks }}</div>
                    {% else %}
                        <p class="empty text-center">{% trans "Empty content" %}</p>
                    {% endif %}
                {% endif %}
            {% endif %}
        </div>
        {% if previous_day %}<a 
        href="{% url 'datebook-author-day' author=author year=datebook.period.year month=datebook.period.month day=previous_day.activity_date.day %}" 
        class="button small modal-navigation-day previous" 
        data-from-id="{{ datebook.period.year }}-{{ datebook.period.month }}-{{ object.activity_date.day }}" 
        data-target-id="{{ datebook.period.year }}-{{ datebook.period.month }}-{{ previous_day.activity_date.day }}"
        title="{% trans "Previous" %}">
            <i class="icon-arrow-left"></i>
        </a>{% endif %}
        {% if next_day %}<a 
        href="{% url 'datebook-author-day' author=author year=datebook.period.year month=datebook.period.month day=next_day.activity_date.day %}"
        class="button small modal-navigation-day next" 
        data-from-id="{{ datebook.period.year }}-{{ datebook.period.month }}-{{ object.activity_date.day }}" 
        data-target-id="{{ datebook.period.year }}-{{ datebook.period.month }}-{{ next_day.activity_date.day }}"
        title="{% trans "Next" %}">
            <i class="icon-arrow-right"></i>
        </a>{% endif %}
    </div>
    {% comment %}<a class="close-reveal-modal">&#215;</a>{% endcomment %}
</div>
